#
# spec file for package switchboard
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   2_0-0
Name:           switchboard
Version:        2.3.4
Release:        lp151.1.1
Summary:        Modular Desktop Settings Hub
License:        LGPL-2.1-only AND LGPL-3.0-only
Group:          System/GUI/Other
URL:            https://elementary.io/
Source:         https://github.com/elementary/switchboard/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson >= 0.46.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(clutter-gtk-1.0)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10
BuildRequires:  pkgconfig(vapigen) >= 0.28.0
Recommends:     %{name}-lang

%description
Switchboard is a modular system settings hub designed for the Pantheon desktop.

%package -n     lib%{name}-%{sover}
Summary:        Modular Desktop Settings Hub
Group:          System/Libraries

%description -n lib%{name}-%{sover}
This package contains the shared library required to run the plugs.

%package        devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}-%{sover} = %{version}

%description    devel
Switchboard is a modular system settings hub designed for the Pantheon desktop.

This package contains development files needed to develop plugins for
%{name}.

%lang_package

%prep
%setup -q

%build
%meson \
  -Dlibunity=false
%meson_build

%install
%meson_install
%suse_update_desktop_file io.elementary.switchboard -r System HardwareSettings
%find_lang io.elementary.switchboard %{name}.lang
%fdupes %{buildroot}%{_datadir}

%post   -n lib%{name}-%{sover} -p /sbin/ldconfig
%postun -n lib%{name}-%{sover} -p /sbin/ldconfig

%files
%license COPYING
%doc README.md
%{_bindir}/io.elementary.switchboard
%{_datadir}/applications/io.elementary.switchboard.desktop
%{_datadir}/glib-2.0/schemas/io.elementary.switchboard.gschema.xml
%{_datadir}/metainfo/io.elementary.switchboard.appdata.xml

%files -n lib%{name}-%{sover}
%{_libdir}/libswitchboard*.so.*

%files devel
%{_includedir}/switchboard*/
%{_libdir}/libswitchboard*.so
%{_libdir}/pkgconfig/switchboard*.pc
%{_datadir}/vala/vapi/switchboard*.deps
%{_datadir}/vala/vapi/switchboard*.vapi

%files lang -f %{name}.lang

%changelog
* Thu Dec 20 2018 Jan Engelhardt <jengelh@inai.de>
- Restore "the" in descriptions. Move summaries to Summary:.
* Thu Oct 18 2018 Alexei Podvalsky <avvissu@yandex.by>
- Remove accountsservice-ubuntu-schemas dependency
* Wed Oct 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.4:
  * Use the correct gettext domain (#89)
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.3:
  * Merge branch 'origin/master' into Weblate
  * RDNN binary name (#80)
  * Use GLib.Action accels for go back shortcut (#79)
  * Switchboard.vala: fix deprecated methods (#77)
- Switch to meson
* Fri Aug 17 2018 avvissu@yandex.by
- Update to 2.3.2:
  * Switch to Meson build system (#75)
  * Add EditorConfig
  * ReadMe: Add link to Valadoc (#74)
  * Add a screenshot to appdata (#69)
* Mon Jun 11 2018 avvissu@yandex.by
- Update to 2.3.1:
  * RDNN metadata (#61)
  * Valign category separators (#60)
  * plug: handle plug visibility the right way (#56)
  * plugs-manager: check for the .so suffix before doing anything
  * switchboard: use Gtk.Application instead of the deprecated
    Granite.Application (#57)
* Sat Jun  9 2018 avvissu@yandex.by
- Add accountsservice-ubuntu-schemas as required dependency
- Change the LIBDIR variable
- Remove obsolete macros
- Spec file cleanup
* Sat Jul 29 2017 avvissu@yandex.by
- Update to 2.3.0:
  * Update switchboard.appdata.xml.in (#41)
  * Create CODE_OF_CONDUCT.md (#38)
- Change the sourceurl to git
* Tue Jun 13 2017 jengelh@inai.de
- Clarify description.
* Mon Jun  5 2017 avvissu@yandex.by
- Remove required dependency: accountsservice-ubuntu-schemas
* Thu Feb  2 2017 avvissu@yandex.by
- Update to 2.2.1:
  * Fix printf being used before translating the string
  * Don't kill kittens
  * Handle can-show changes properly
  * Implement fallback to "parent" setting path
* Fri Dec  9 2016 avvissu@yandex.by
- Update to 2.2.0
* Sun Sep 18 2016 avvissu@yandex.by
- Update to 2.1.0
- Add macro glib2_gsettings_schema_requires
- Use macro: cmake and cmake_install
- Spec file cleanup
* Sat Feb 27 2016 mailaender@opensuse.org
- update to version 2.0.1
* Sat May 16 2015 mailaender@opensuse.org
- initial packaging of version 2.0.0
